<?php
/**
 * This file implements the Digg plugin.
 *
 * Once it's installed you can add a Digg.com button to your posts using the Digg renderer checkbox
 * If you want all posts to have the button, just set the renderer to 'always'.  You can also change
 * the button size and position in the plugin settings.
 *
 */
if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );


class am_digg_plugin extends Plugin
{
	var $name = 'AstonishMe Digg';
	var $code = 'am_digg';
	var $priority = 100; // Needs to be higher than Texturizer
	var $version = '2.2.2';
	var $author = 'Danny Ferguson';
	var $help_url = 'http://b2evo.astonishme.co.uk/index.php/2007/02/09/astonishme_digg_plugin';  
	var $apply_rendering = 'opt-in';
	var $number_of_installs = 1;
	var $group = 'AstonishMe';


	function PluginInit( & $params )
	{
		$this->short_desc = T_('Digg links for your posts');
		$this->long_desc = T_('Add a button for each post that allows users to submit your posts to Digg.com and to see how many diggs your posts have.');
	}

	function GetDefaultSettings()
	{
		return array(
		'button' => array(
			'label' => T_( 'Digg button size' ),
			'note' => T_('Do you want the normal button as it appears on Digg.com or the compact button?'),
			'type' => 'select',
			'options' => array('normal' => 'Normal', 'compact' => 'Compact'),
			'defaultvalue' => 'normal'
			),
		'placement' => array(
			'label' => T_( 'Digg button placement' ),
			'note' => T_('Do you want the button floated left at the top of your post, at the bottom or your post or manually placed with a skintag?  To place it manually, put this code into your skin:  <?php $Plugins->call_by_code( \'am_digg\', array(\'id\' => $Item->ID ) ); ?>.'),
			'type' => 'select',
			'defaultvalue' => 'top',
			'options' => array('top' => 'Top', 'bottom' => 'Bottom', 'manual' => 'Manual')
			),
		'suggest_title' => array(
			'label' => T_( 'Suggest title' ),
			'defaultvalue' => 1,
			'note' => T_( 'Do you want your post title to be the suggested Digg story title?  The submitter can still change it.'),
			'type' => 'checkbox'
			),
		'suggest_desc' => array(
			'label' => T_( 'Suggest description' ),
			'defaultvalue' => 1,
			'note' => T_( 'Do you want your post content to be the suggested Digg story description?  The submitter can still change it.  Your post will will be trimmed to 325 characters.'),
			'type' => 'checkbox'
			)
			);
	}

	/**
	 * Event handlers:
	 */

	/**
	 * Event handler: Called when displaying item/post contents as HTML.
	 */
	function RenderItemAsHtml( & $params )
	{
		if ($this->Settings->get('placement') == 'top') {
			$params['data'] = "<div style='float:left;margin-right: 5px'>".$this->DiggButton( $params )."</div>".$params['data'];
		} elseif ($this->Settings->get('placement') == 'bottom') {
			$params['data'] = $params['data']."<br />".$this->DiggButton( $params );
		}
	}

	/* 
	 * If you want to add the button manually, rather than using top or bottom positioning,
	 * call like this somewhere in the posts loop:
	 *   <?php $Plugins->call_by_code( 'digg', array('id' => $Item->ID ) ); ?>
	 * You can also add these parameter:
	 *    'before' => Code to be displayed before the button
	 *    'after' => Code to be displayed after the button
	 *    'bgcolor' => Background color for the digg button iframe
	 *    'button' => compact or normal  This will override the backoffice setting
	 */

	function SkinTag( $params )
	{
		global $Item, $Plugins;

		if ($this->Settings->get('placement') == 'manual') {
			// Check to see if we want a rating for this post
			$renders = $Plugins->validate_list( $Item->get_renderers() );
			// If the renderer checkbox is unchecked, then display nothing
			if (!in_array($this->code, $renders)) return false;
			// The renderer is selected, go ahead and display the button
			if (isset($params['before'])) print $params['before'];
			print $this->DiggButton( $params );
			if (isset($params['after'])) print $params['after'];

		}
	}

	function DiggButton( & $params )
	{
		global $Item;
		if (!is_object($Item))
		{
			// The backoffice has to access $Item a little differently
			$Item = $params['Item'];
		}
		
		if(!isset($params['bgcolor'])) $params['bgcolor'] = '#FFFFFF';
		if(!isset($params['button'])) $params['button'] = $this->Settings->get('button');

		$url = $Item->get_permanent_url('', '', '&');
		$title = addslashes($Item->title);
		$content = addslashes(substr(strip_tags($Item->content), 0, 325));
		
		// Strip line breaks, too
		$breaks = array("\n", "\r");
		$content = str_replace($breaks, ' ', $content);
		
		// use js replace to get rid of amp;, which is added on by b2evolution 
		$button = "\n<script type='text/javascript'>digg_url = '$url';\n digg_url = digg_url.replace(/amp;/g, ''); \n digg_bgcolor = '".$params['bgcolor']."';\n";

		if ($params['button'] == 'compact') $button .= "digg_skin = 'compact';\n";
		if ($this->Settings->get('suggest_title')) $button .= "digg_title = '$title';\n";
		if ($this->Settings->get('suggest_desc')) $button .= "digg_bodytext = '$content';\n";

		$button .= "</script>
			<script src='http://digg.com/tools/diggthis.js' type='text/javascript'></script>";
		return $button;
	}

	/**
	 * Clear the prerendered item cache after editing plugin settings so the changes take effect
	 */
	function PluginSettingsUpdateAction()
	{
		global $DB, $Messages;
		$DB->query('DELETE FROM T_items__prerendering WHERE 1=1');
		$Messages->add( sprintf( T_('Removed %d cached entries.'), $DB->rows_affected ), 'success' );
	}
}
?>